@@ -5,14 +5,14 @@ from mw_python_sdk import download_file
 
 class TestDownloadFile(unittest.TestCase):
     def test_download(self):
-        dataset_id_tmp = "64e6c644c60d2823b0a2e266"
+        dataset_id_tmp = "66b08ec9898e74a8232bb2d1"
         try:  # Example assertion
-            download_file(dataset_id_tmp, "flask.zip")
+            download_file(dataset_id_tmp, "b_local_dir/heart_2020_cleaned.csv")
         except Exception as err:
             print(f"An error occurred: {err}")
 
-    def test_redownload(self):
-        dataset_id_tmp = "64e6c644c60d2823b0a2e266"
+    def test_download_again(self):
+        dataset_id_tmp = "66b08ec9898e74a8232bb2d1"
         try:  # Example assertion
             download_file(dataset_id_tmp, "flask.zip")
             download_file(dataset_id_tmp, "flask.zip")
@@ -20,7 +20,7 @@ class TestDownloadFile(unittest.TestCase):
             print(f"An error occurred: {err}")
 
     def test_download_local(self):
-        dataset_id_tmp = "64e6c644c60d2823b0a2e266"
+        dataset_id_tmp = "66b08ec9898e74a8232bb2d1"
         try:  # Example assertion
             download_file(
                 dataset_id_tmp, "flask.zip", local_dir=os.getcwd() + ("/downloads")
